# ns_record

支持修改多个云服务中的域名DNS记录

## HISTORY

* 20180226

支持腾讯云

## Build and upload to pypi

> make push

## INSTALL

> pip install ns_record

## RUN

```bash
$ export TX_Secret_Id=''
$ export TX_Secret_Key=''
$ ns_record_mod newops.cn pi 112.193.48.124
```
